import 'package:vectorx/vectorx.dart';
import 'package:vectorx/vectorx/utils.dart';
import 'package:flutter/widgets.dart';

class AlignWidgetParser extends WidgetParser {
  @override
  Widget parse(Map<String, dynamic> map, BuildContext buildContext,
      ClickListener listener) {
    return Align(
      alignment: map.containsKey("alignment")
          ? parseAlignment(map["alignment"])
          : Alignment.center,
      widthFactor: map.containsKey("widthFactor")
          ? map["widthFactor"]?.toDouble()
          : null,
      heightFactor: map.containsKey("heightFactor")
          ? map["heightFactor"]?.toDouble()
          : null,
      child: VectorXBuilder.buildFromMap(map["child"], buildContext, listener),
    );
  }

  @override
  String get widgetName => "Align";

  @override
  Map<String, dynamic> export(Widget widget, BuildContext buildContext) {
    var realWidget = widget as Align;
    var alignment = realWidget.alignment as Alignment;
    var child = realWidget.child as Widget;
    Map<String, dynamic> json = {
      "type": widgetName,
      "alignment": exportAlignment(alignment),
      "widthFactor": realWidget.widthFactor,
      "heightFactor": realWidget.heightFactor,
      "child": VectorXBuilder.export(child, buildContext)
    };
    return json;
  }

  @override
  Type get widgetType => Align;
}
